from rdflib import URIRef

# WARNING. This is a Generated File. Please do not edit.
# Please refer to the README at java/src/main/java/com/ncc/aif/ont2javagen for more information
# Last generated on: 08/24/2020 11:09:20
NAMESPACE = 'https://raw.githubusercontent.com/NextCenturyCorporation/AIDA-Interchange-Format/master/java/src/main/resources/com/ncc/aif/ontologies/ExtendedEntity#'

# Classes
ActivityField = URIRef(NAMESPACE + 'ActivityField')
Address = URIRef(NAMESPACE + 'Address')
AdministrativeUnit = URIRef(NAMESPACE + 'AdministrativeUnit')
Administrator = URIRef(NAMESPACE + 'Administrator')
Agency = URIRef(NAMESPACE + 'Agency')
AirForce = URIRef(NAMESPACE + 'AirForce')
Aircraft = URIRef(NAMESPACE + 'Aircraft')
Aircraft_cabin = URIRef(NAMESPACE + 'Aircraft_cabin')
Aircraft_carrier = URIRef(NAMESPACE + 'Aircraft_carrier')
Airplane = URIRef(NAMESPACE + 'Airplane')
Airport = URIRef(NAMESPACE + 'Airport')
Album = URIRef(NAMESPACE + 'Album')
Ambassador = URIRef(NAMESPACE + 'Ambassador')
Ambulance = URIRef(NAMESPACE + 'Ambulance')
American_flag = URIRef(NAMESPACE + 'American_flag')
Animal = URIRef(NAMESPACE + 'Animal')
Anti_aircraft = URIRef(NAMESPACE + 'Anti_aircraft')
Army = URIRef(NAMESPACE + 'Army')
Artifact = URIRef(NAMESPACE + 'Artifact')
Assault_rifle = URIRef(NAMESPACE + 'Assault_rifle')
Association = URIRef(NAMESPACE + 'Association')
Athlete = URIRef(NAMESPACE + 'Athlete')
Audience = URIRef(NAMESPACE + 'Audience')
Auditorium = URIRef(NAMESPACE + 'Auditorium')
Auto_part = URIRef(NAMESPACE + 'Auto_part')
Back_pack = URIRef(NAMESPACE + 'Back_pack')
Ballistic_vest = URIRef(NAMESPACE + 'Ballistic_vest')
Ballot = URIRef(NAMESPACE + 'Ballot')
Barge = URIRef(NAMESPACE + 'Barge')
Barricade = URIRef(NAMESPACE + 'Barricade')
Bat = URIRef(NAMESPACE + 'Bat')
Bicycle = URIRef(NAMESPACE + 'Bicycle')
Billboard = URIRef(NAMESPACE + 'Billboard')
BiologicalWeapon = URIRef(NAMESPACE + 'BiologicalWeapon')
Boat = URIRef(NAMESPACE + 'Boat')
BodyOfWater = URIRef(NAMESPACE + 'BodyOfWater')
Bomb = URIRef(NAMESPACE + 'Bomb')
Bomber = URIRef(NAMESPACE + 'Bomber')
Branch = URIRef(NAMESPACE + 'Branch')
Bridge = URIRef(NAMESPACE + 'Bridge')
Broadcaster = URIRef(NAMESPACE + 'Broadcaster')
BroadcastingCompany = URIRef(NAMESPACE + 'BroadcastingCompany')
BroadcastingStation = URIRef(NAMESPACE + 'BroadcastingStation')
Building = URIRef(NAMESPACE + 'Building')
BuildingConstruction = URIRef(NAMESPACE + 'BuildingConstruction')
Buk_missile = URIRef(NAMESPACE + 'Buk_missile')
Bullets = URIRef(NAMESPACE + 'Bullets')
Bus = URIRef(NAMESPACE + 'Bus')
Bus_stop = URIRef(NAMESPACE + 'Bus_stop')
Businessperson = URIRef(NAMESPACE + 'Businessperson')
Cable = URIRef(NAMESPACE + 'Cable')
Cannon = URIRef(NAMESPACE + 'Cannon')
Cape = URIRef(NAMESPACE + 'Cape')
Car = URIRef(NAMESPACE + 'Car')
Cargo_aircraft = URIRef(NAMESPACE + 'Cargo_aircraft')
Cash = URIRef(NAMESPACE + 'Cash')
Cathedral = URIRef(NAMESPACE + 'Cathedral')
Chapel = URIRef(NAMESPACE + 'Chapel')
Church = URIRef(NAMESPACE + 'Church')
City = URIRef(NAMESPACE + 'City')
Club = URIRef(NAMESPACE + 'Club')
Collection = URIRef(NAMESPACE + 'Collection')
Combatant = URIRef(NAMESPACE + 'Combatant')
CommercialEnterprise = URIRef(NAMESPACE + 'CommercialEnterprise')
CommercialOrg = URIRef(NAMESPACE + 'CommercialOrg')
Committee = URIRef(NAMESPACE + 'Committee')
Commodity = URIRef(NAMESPACE + 'Commodity')
Compiler = URIRef(NAMESPACE + 'Compiler')
Computer = URIRef(NAMESPACE + 'Computer')
Computer_monitor = URIRef(NAMESPACE + 'Computer_monitor')
Conference_hall = URIRef(NAMESPACE + 'Conference_hall')
Construction_equipment = URIRef(NAMESPACE + 'Construction_equipment')
Container = URIRef(NAMESPACE + 'Container')
Contestant = URIRef(NAMESPACE + 'Contestant')
Continent = URIRef(NAMESPACE + 'Continent')
Convenience_store = URIRef(NAMESPACE + 'Convenience_store')
Corporation = URIRef(NAMESPACE + 'Corporation')
Country = URIRef(NAMESPACE + 'Country')
Court = URIRef(NAMESPACE + 'Court')
Courthouse = URIRef(NAMESPACE + 'Courthouse')
Craft = URIRef(NAMESPACE + 'Craft')
Creation = URIRef(NAMESPACE + 'Creation')
Crowd = URIRef(NAMESPACE + 'Crowd')
Cruise_ship = URIRef(NAMESPACE + 'Cruise_ship')
Dagger = URIRef(NAMESPACE + 'Dagger')
DanceBand = URIRef(NAMESPACE + 'DanceBand')
Department = URIRef(NAMESPACE + 'Department')
Depository = URIRef(NAMESPACE + 'Depository')
Device = URIRef(NAMESPACE + 'Device')
Director = URIRef(NAMESPACE + 'Director')
Division = URIRef(NAMESPACE + 'Division')
Dog = URIRef(NAMESPACE + 'Dog')
Dome = URIRef(NAMESPACE + 'Dome')
Double_decker_bus = URIRef(NAMESPACE + 'Double-decker_bus')
Engine = URIRef(NAMESPACE + 'Engine')
Engineer = URIRef(NAMESPACE + 'Engineer')
Entity = URIRef(NAMESPACE + 'Entity')
Equipment = URIRef(NAMESPACE + 'Equipment')
Executive = URIRef(NAMESPACE + 'Executive')
Exile = URIRef(NAMESPACE + 'Exile')
Facility = URIRef(NAMESPACE + 'Facility')
Fence = URIRef(NAMESPACE + 'Fence')
Ferry = URIRef(NAMESPACE + 'Ferry')
Fighter_aircraft = URIRef(NAMESPACE + 'Fighter_aircraft')
Fire_apparatus = URIRef(NAMESPACE + 'Fire_apparatus')
Fire_extinguisher = URIRef(NAMESPACE + 'Fire_extinguisher')
Firearm = URIRef(NAMESPACE + 'Firearm')
Firefighter = URIRef(NAMESPACE + 'Firefighter')
Flag = URIRef(NAMESPACE + 'Flag')
Food = URIRef(NAMESPACE + 'Food')
Fugitive = URIRef(NAMESPACE + 'Fugitive')
Furniture = URIRef(NAMESPACE + 'Furniture')
GPE = URIRef(NAMESPACE + 'GPE')
Game = URIRef(NAMESPACE + 'Game')
Gas_station = URIRef(NAMESPACE + 'Gas_station')
GeneralCrime = URIRef(NAMESPACE + 'GeneralCrime')
GeographicPoint = URIRef(NAMESPACE + 'GeographicPoint')
GeographicalArea = URIRef(NAMESPACE + 'GeographicalArea')
Goggles = URIRef(NAMESPACE + 'Goggles')
GovernmentBuilding = URIRef(NAMESPACE + 'GovernmentBuilding')
Governor = URIRef(NAMESPACE + 'Governor')
GuidedMissile = URIRef(NAMESPACE + 'GuidedMissile')
Gun = URIRef(NAMESPACE + 'Gun')
Handgun = URIRef(NAMESPACE + 'Handgun')
Helicopter = URIRef(NAMESPACE + 'Helicopter')
Helmet = URIRef(NAMESPACE + 'Helmet')
Highway = URIRef(NAMESPACE + 'Highway')
House = URIRef(NAMESPACE + 'House')
Human_body = URIRef(NAMESPACE + 'Human_body')
Human_face = URIRef(NAMESPACE + 'Human_face')
Human_head = URIRef(NAMESPACE + 'Human_head')
INFO = URIRef(NAMESPACE + 'INFO')
ImageInfo = URIRef(NAMESPACE + 'ImageInfo')
ImmeasurableObject = URIRef(NAMESPACE + 'ImmeasurableObject')
InfoMedium = URIRef(NAMESPACE + 'InfoMedium')
InformationObject = URIRef(NAMESPACE + 'InformationObject')
Instrument = URIRef(NAMESPACE + 'Instrument')
Intellectual = URIRef(NAMESPACE + 'Intellectual')
Island = URIRef(NAMESPACE + 'Island')
Journalist = URIRef(NAMESPACE + 'Journalist')
Land = URIRef(NAMESPACE + 'Land')
Law = URIRef(NAMESPACE + 'Law')
LawEnforcementAgency = URIRef(NAMESPACE + 'LawEnforcementAgency')
Lawgiver = URIRef(NAMESPACE + 'Lawgiver')
Lawman = URIRef(NAMESPACE + 'Lawman')
League = URIRef(NAMESPACE + 'League')
Lectern = URIRef(NAMESPACE + 'Lectern')
Legislator = URIRef(NAMESPACE + 'Legislator')
Lifejacket = URIRef(NAMESPACE + 'Lifejacket')
Lighthouse = URIRef(NAMESPACE + 'Lighthouse')
Limousine = URIRef(NAMESPACE + 'Limousine')
LivingBodyPart = URIRef(NAMESPACE + 'LivingBodyPart')
Loc = URIRef(NAMESPACE + 'Loc')
Locomotive = URIRef(NAMESPACE + 'Locomotive')
Logo_Trademark_Emblem_Badge = URIRef(NAMESPACE + 'Logo_Trademark_Emblem_Badge')
Luggage_and_bags = URIRef(NAMESPACE + 'Luggage_and_bags')
Machine = URIRef(NAMESPACE + 'Machine')
Machine_gun = URIRef(NAMESPACE + 'Machine_gun')
Magazine = URIRef(NAMESPACE + 'Magazine')
Manufacturer = URIRef(NAMESPACE + 'Manufacturer')
Map = URIRef(NAMESPACE + 'Map')
Mayor = URIRef(NAMESPACE + 'Mayor')
MeasurableAbstraction = URIRef(NAMESPACE + 'MeasurableAbstraction')
MeasuredConcept = URIRef(NAMESPACE + 'MeasuredConcept')
MeasuringUnit = URIRef(NAMESPACE + 'MeasuringUnit')
Medical_equipment = URIRef(NAMESPACE + 'Medical_equipment')
Medicine = URIRef(NAMESPACE + 'Medicine')
MentalObject = URIRef(NAMESPACE + 'MentalObject')
Microphone = URIRef(NAMESPACE + 'Microphone')
Militant = URIRef(NAMESPACE + 'Militant')
MilitaryInstallation = URIRef(NAMESPACE + 'MilitaryInstallation')
MilitaryOfficer = URIRef(NAMESPACE + 'MilitaryOfficer')
MilitaryOrg = URIRef(NAMESPACE + 'MilitaryOrg')
Military_aircraft = URIRef(NAMESPACE + 'Military_aircraft')
Military_transport_aircraft = URIRef(NAMESPACE + 'Military_transport_aircraft')
Military_uniform = URIRef(NAMESPACE + 'Military_uniform')
Military_vehicle = URIRef(NAMESPACE + 'Military_vehicle')
Minister = URIRef(NAMESPACE + 'Minister')
Missile = URIRef(NAMESPACE + 'Missile')
Missile_launcher = URIRef(NAMESPACE + 'Missile_launcher')
Money = URIRef(NAMESPACE + 'Money')
Monument = URIRef(NAMESPACE + 'Monument')
Motorcycle = URIRef(NAMESPACE + 'Motorcycle')
Mountain = URIRef(NAMESPACE + 'Mountain')
MusicInfo = URIRef(NAMESPACE + 'MusicInfo')
MusicalOrganization = URIRef(NAMESPACE + 'MusicalOrganization')
NaturalNonLivingObject = URIRef(NAMESPACE + 'NaturalNonLivingObject')
Navy = URIRef(NAMESPACE + 'Navy')
NewsAgency = URIRef(NAMESPACE + 'NewsAgency')
NewsMedium = URIRef(NAMESPACE + 'NewsMedium')
Newspaper = URIRef(NAMESPACE + 'Newspaper')
NonHumanLivingBeing = URIRef(NAMESPACE + 'NonHumanLivingBeing')
NonLivingTangiblePart = URIRef(NAMESPACE + 'NonLivingTangiblePart')
NonOrgGroup = URIRef(NAMESPACE + 'NonOrgGroup')
NonPhysicalEntity = URIRef(NAMESPACE + 'NonPhysicalEntity')
Office_building = URIRef(NAMESPACE + 'Office_building')
Org = URIRef(NAMESPACE + 'Org')
PER = URIRef(NAMESPACE + 'PER')
Parachute = URIRef(NAMESPACE + 'Parachute')
Paramedics = URIRef(NAMESPACE + 'Paramedics')
Park = URIRef(NAMESPACE + 'Park')
Party = URIRef(NAMESPACE + 'Party')
Passenger_ship = URIRef(NAMESPACE + 'Passenger_ship')
Peninsula = URIRef(NAMESPACE + 'Peninsula')
Person = URIRef(NAMESPACE + 'Person')
Phone = URIRef(NAMESPACE + 'Phone')
PhysicalEntity = URIRef(NAMESPACE + 'PhysicalEntity')
Pier = URIRef(NAMESPACE + 'Pier')
Place_of_worship = URIRef(NAMESPACE + 'Place_of_worship')
Player = URIRef(NAMESPACE + 'Player')
Plaza = URIRef(NAMESPACE + 'Plaza')
Podium = URIRef(NAMESPACE + 'Podium')
Point = URIRef(NAMESPACE + 'Point')
Police = URIRef(NAMESPACE + 'Police')
Police_car = URIRef(NAMESPACE + 'Police_car')
Police_dog = URIRef(NAMESPACE + 'Police_dog')
PoliticalOrg = URIRef(NAMESPACE + 'PoliticalOrg')
Politician = URIRef(NAMESPACE + 'Politician')
Politics = URIRef(NAMESPACE + 'Politics')
Port = URIRef(NAMESPACE + 'Port')
Position = URIRef(NAMESPACE + 'Position')
Poster = URIRef(NAMESPACE + 'Poster')
Press = URIRef(NAMESPACE + 'Press')
Propeller_driven_aircraft = URIRef(NAMESPACE + 'Propeller-driven_aircraft')
PublicSquare = URIRef(NAMESPACE + 'PublicSquare')
Radar = URIRef(NAMESPACE + 'Radar')
Radical = URIRef(NAMESPACE + 'Radical')
Railway = URIRef(NAMESPACE + 'Railway')
Relation = URIRef(NAMESPACE + 'Relation')
Reporter = URIRef(NAMESPACE + 'Reporter')
Rescuers = URIRef(NAMESPACE + 'Rescuers')
Rifle = URIRef(NAMESPACE + 'Rifle')
Riot_police = URIRef(NAMESPACE + 'Riot_police')
RockGroup = URIRef(NAMESPACE + 'RockGroup')
Rocket = URIRef(NAMESPACE + 'Rocket')
Rubble = URIRef(NAMESPACE + 'Rubble')
Ruins = URIRef(NAMESPACE + 'Ruins')
Ruler = URIRef(NAMESPACE + 'Ruler')
Russian_flag = URIRef(NAMESPACE + 'Russian_flag')
Sailboat = URIRef(NAMESPACE + 'Sailboat')
Satellite = URIRef(NAMESPACE + 'Satellite')
Scholar = URIRef(NAMESPACE + 'Scholar')
Science = URIRef(NAMESPACE + 'Science')
Scientist = URIRef(NAMESPACE + 'Scientist')
Sculpture = URIRef(NAMESPACE + 'Sculpture')
Senator = URIRef(NAMESPACE + 'Senator')
Sentence = URIRef(NAMESPACE + 'Sentence')
Serviceman = URIRef(NAMESPACE + 'Serviceman')
ShapeAndStructureAbstraction = URIRef(NAMESPACE + 'ShapeAndStructureAbstraction')
Ship = URIRef(NAMESPACE + 'Ship')
Shish = URIRef(NAMESPACE + 'Shish')
Shotgun = URIRef(NAMESPACE + 'Shotgun')
Shrine = URIRef(NAMESPACE + 'Shrine')
Skyscraper = URIRef(NAMESPACE + 'Skyscraper')
Smoke = URIRef(NAMESPACE + 'Smoke')
Sniper = URIRef(NAMESPACE + 'Sniper')
SocialGroup = URIRef(NAMESPACE + 'SocialGroup')
SocialMedium = URIRef(NAMESPACE + 'SocialMedium')
Source_Ontology = URIRef(NAMESPACE + 'Source_Ontology')
Spacecraft = URIRef(NAMESPACE + 'Spacecraft')
Speaker = URIRef(NAMESPACE + 'Speaker')
SpeechInfo = URIRef(NAMESPACE + 'SpeechInfo')
Spokesperson = URIRef(NAMESPACE + 'Spokesperson')
Spy = URIRef(NAMESPACE + 'Spy')
Station = URIRef(NAMESPACE + 'Station')
Statue = URIRef(NAMESPACE + 'Statue')
Stream = URIRef(NAMESPACE + 'Stream')
Street = URIRef(NAMESPACE + 'Street')
Stretcher = URIRef(NAMESPACE + 'Stretcher')
Structure = URIRef(NAMESPACE + 'Structure')
Subdivision = URIRef(NAMESPACE + 'Subdivision')
Submarine = URIRef(NAMESPACE + 'Submarine')
SubsidiaryCompany = URIRef(NAMESPACE + 'SubsidiaryCompany')
Surface_to_airMissile = URIRef(NAMESPACE + 'Surface-to-airMissile')
Surveillance_camera = URIRef(NAMESPACE + 'Surveillance_camera')
Tank = URIRef(NAMESPACE + 'Tank')
Taxi = URIRef(NAMESPACE + 'Taxi')
Team = URIRef(NAMESPACE + 'Team')
Tear_gas = URIRef(NAMESPACE + 'Tear_gas')
Television = URIRef(NAMESPACE + 'Television')
Television_set = URIRef(NAMESPACE + 'Television_set')
Temple = URIRef(NAMESPACE + 'Temple')
Tent = URIRef(NAMESPACE + 'Tent')
TextInfo = URIRef(NAMESPACE + 'TextInfo')
Theater = URIRef(NAMESPACE + 'Theater')
Time = URIRef(NAMESPACE + 'Time')
Title = URIRef(NAMESPACE + 'Title')
Tool = URIRef(NAMESPACE + 'Tool')
TopographicPoint = URIRef(NAMESPACE + 'TopographicPoint')
Tower = URIRef(NAMESPACE + 'Tower')
Town = URIRef(NAMESPACE + 'Town')
Tract = URIRef(NAMESPACE + 'Tract')
Tractor = URIRef(NAMESPACE + 'Tractor')
Traffic_light = URIRef(NAMESPACE + 'Traffic_light')
Trailer_truck = URIRef(NAMESPACE + 'Trailer_truck')
Train = URIRef(NAMESPACE + 'Train')
Train_station = URIRef(NAMESPACE + 'Train_station')
Traveler = URIRef(NAMESPACE + 'Traveler')
Truck = URIRef(NAMESPACE + 'Truck')
Ukraine_flag = URIRef(NAMESPACE + 'Ukraine_flag')
Uniform = URIRef(NAMESPACE + 'Uniform')
Union = URIRef(NAMESPACE + 'Union')
UrbanArea = URIRef(NAMESPACE + 'UrbanArea')
Van = URIRef(NAMESPACE + 'Van')
Vehicle = URIRef(NAMESPACE + 'Vehicle')
Water_cannon = URIRef(NAMESPACE + 'Water_cannon')
Watercraft = URIRef(NAMESPACE + 'Watercraft')
Way = URIRef(NAMESPACE + 'Way')
Weapon = URIRef(NAMESPACE + 'Weapon')
WheeledVehicle = URIRef(NAMESPACE + 'WheeledVehicle')
WorldOrganization = URIRef(NAMESPACE + 'WorldOrganization')
Wreckage = URIRef(NAMESPACE + 'Wreckage')
Writer = URIRef(NAMESPACE + 'Writer')
Yacht = URIRef(NAMESPACE + 'Yacht')
Zone = URIRef(NAMESPACE + 'Zone')
